@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2024, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,11 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <cxxabi.h>
+
 #include "errorcheck.h"
 #include <drumstick/alsaevent.h>
+
 /**
  * @file alsaevent.cpp
  * Implementation of classes managing ALSA Sequencer events.
@@ -92,7 +95,6 @@ namespace drumstick { namespace ALSA {
  * @}
  */
 
-
 /**
  * Default constructor.
  */
@@ -1263,6 +1265,29 @@ MidiCodec::resizeBuffer(int bufsize)
     DRUMSTICK_ALSA_CHECK_WARNING(snd_midi_event_resize_buffer(m_Info, bufsize));
 }
 
+QString typeOfEvent(const SequencerEvent &v)
+{
+    int status;
+    char *realname = abi::__cxa_demangle(typeid(v).name(), 0, 0, &status);
+    QString name(realname && realname[0] ? realname : "drumstick::ALSA::SequencerEvent");
+    free(realname);
+    return name;
+}
+
+QDebug operator<<(QDebug d, const SequencerEvent &event)
+{
+    QDebugStateSaver saver(d);
+    d.noquote() << typeOfEvent(event);
+    return d;
+}
+
+QDebug operator<<(QDebug d, const SequencerEvent *event)
+{
+    QDebugStateSaver saver(d);
+    d.noquote().nospace() << typeOfEvent(*event) << "*";
+    return d;
+}
+
 } // namespace ALSA
 } // namespace drumstick
 
