@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2024, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,6 +16,8 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <QMetaMethod>
+
 #include "errorcheck.h"
 #include <drumstick/alsaclient.h>
 #include <drumstick/alsaqueue.h>
@@ -638,9 +640,12 @@ MidiPort::setMidiClient( MidiClient* seq )
 void
 MidiPort::subscribe(Subscription* subs)
 {
+    static const QMetaMethod subscribedSignal = QMetaMethod::fromSignal(&MidiPort::subscribed);
     subs->subscribe(m_MidiClient);
     m_Subscriptions.append(*subs);
-    Q_EMIT subscribed(this, subs);
+    if (isSignalConnected(subscribedSignal)) {
+        Q_EMIT subscribed(this, subs->clone());
+    }
 }
 
 /**
