@@ -1,6 +1,6 @@
 /*
     Drumstick RT Windows Backend
-    Copyright (C) 2009-2023 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2024 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -57,6 +57,10 @@ namespace rt {
         bool m_status;
         QStringList m_diagnostics;
 
+        #define SYSEX_BUF_SIZE 32768
+        MIDIHDR inMidiHeader;
+        unsigned char inSysexBuf[SYSEX_BUF_SIZE];
+
         explicit WinMIDIInputPrivate(WinMIDIInput *inp):
             m_inp(inp),
             m_out(nullptr),
@@ -68,6 +72,11 @@ namespace rt {
             reloadDeviceList(true);
         }
 
+        ~WinMIDIInputPrivate()
+        {
+            close();
+        }
+
         void open(const MIDIConnection &conn) {
             MMRESULT res;
             m_status = false;
@@ -81,9 +90,29 @@ namespace rt {
                     if (res != MMSYSERR_NOERROR) {
                         logError("midiInOpen()",res);
                     } else {
+                        /* Double buffering configuration, to manage Sysexes */
+                        /* Store pointer to our input buffer for System Exclusive messages in MIDIHDR */
+                        inMidiHeader.lpData = (LPSTR)&inSysexBuf[0];
+
+                        /* Store its size in the MIDIHDR */
+                        inMidiHeader.dwBufferLength = SYSEX_BUF_SIZE;
+
+                        /* Flags must be set to 0 */
+                        inMidiHeader.dwFlags = 0;
+
+                        res = midiInPrepareHeader(m_handle, &inMidiHeader, sizeof(MIDIHDR));
+                        if (res != MMSYSERR_NOERROR){
+                            logError("midiInPrepareHeader()", res);
+                        }
+
+                        res = midiInAddBuffer(m_handle, &inMidiHeader, sizeof(MIDIHDR));
+                        if (res != MMSYSERR_NOERROR){
+                            logError("midiInAddBuffer()", res);
+                        }
+
                         res = midiInStart(m_handle);
                         if (res != MMSYSERR_NOERROR) {
-                            logError("midiInStart()",res);
+                            logError("midiInStart()", res);
                         }
                     }
                     m_currentInput = conn;
@@ -97,6 +126,9 @@ namespace rt {
             m_status = false;
             m_diagnostics.clear();
             if (m_handle != nullptr) {
+                res = midiInUnprepareHeader(m_handle, &inMidiHeader, sizeof(MIDIHDR));
+                if (res != MMSYSERR_NOERROR)
+                    logError("midiInUnprepareHeader()", res);
                 res = midiInStop(m_handle);
                 if (res != MMSYSERR_NOERROR)
                     logError("midiInStop()", res);
@@ -243,8 +275,24 @@ namespace rt {
             object->m_diagnostics << "Errors input";
             break;
         case MIM_LONGDATA:
+        {
             object->m_diagnostics << "Sysex data input";
+            // Extract MIDI SysEx message information
+            MIDIHDR* pMidiHdr = reinterpret_cast<MIDIHDR*>(dwParam1);
+
+            // Check for SysEx messages
+            if (pMidiHdr->dwBytesRecorded > 0 && (unsigned char)pMidiHdr->lpData[0] == 0xF0) // Start of SysEx
+            {
+                QByteArray sysExByteArray(reinterpret_cast<const char*>(pMidiHdr->lpData), static_cast<int>(pMidiHdr->dwBytesRecorded));
+                object->emitSysex(sysExByteArray);
+            }
+            
+            if (object->m_status) {
+                /* Queue the MIDIHDR for more input */
+                midiInAddBuffer(hMidiIn, pMidiHdr, sizeof(MIDIHDR));
+            }
             break;
+        }
         case MIM_DATA:
         case MIM_MOREDATA: {
                 int status = dwParam1 & 0xf0;
