@@ -1,6 +1,6 @@
 /*
     Drumstick MIDI Sequencer C++ library
-    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2024, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,10 +19,11 @@
 #include <QDir>
 #include <QFileDialog>
 #include <QFileInfo>
+#include <QMessageBox>
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QToolButton>
-#include <QMessageBox>
+#include <QToolTip>
 #include <QVersionNumber>
 
 #include "fluidsettingsdialog.h"
@@ -51,6 +52,14 @@ const QString FluidSettingsDialog::QSTR_GAIN = QStringLiteral("Gain");
 const QString FluidSettingsDialog::QSTR_POLYPHONY = QStringLiteral("Polyphony");
 const QString FluidSettingsDialog::QSTR_BUFFERTIME = QStringLiteral("BufferTime");
 const QString FluidSettingsDialog::QSTR_PULSEAUDIO = QStringLiteral("pulseaudio");
+const QString FluidSettingsDialog::QSTR_CHORUS_DEPTH = QStringLiteral("chorus_depth");
+const QString FluidSettingsDialog::QSTR_CHORUS_LEVEL = QStringLiteral("chorus_level");
+const QString FluidSettingsDialog::QSTR_CHORUS_NR = QStringLiteral("chorus_nr");
+const QString FluidSettingsDialog::QSTR_CHORUS_SPEED = QStringLiteral("chorus_speed");
+const QString FluidSettingsDialog::QSTR_REVERB_DAMP = QStringLiteral("reverb_damp");
+const QString FluidSettingsDialog::QSTR_REVERB_LEVEL = QStringLiteral("reverb_level");
+const QString FluidSettingsDialog::QSTR_REVERB_SIZE = QStringLiteral("reverb_size");
+const QString FluidSettingsDialog::QSTR_REVERB_WIDTH = QStringLiteral("reverb_width");
 
 FluidSettingsDialog::FluidSettingsDialog(QWidget *parent) :
     QDialog(parent),
@@ -64,16 +73,38 @@ FluidSettingsDialog::FluidSettingsDialog(QWidget *parent) :
     connect(ui->btnFile, &QToolButton::clicked, this, &FluidSettingsDialog::showFileDialog);
     connect(ui->buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked,
             this, &FluidSettingsDialog::restoreDefaults);
-    auto sampleRateValidator = new QDoubleValidator(8000.0, 96000.0, 1, this);
-    sampleRateValidator->setNotation(QDoubleValidator::StandardNotation);
-    sampleRateValidator->setLocale(QLocale::c());
-    ui->sampleRate->setValidator(sampleRateValidator);
-    auto gainValidator = new QDoubleValidator(0.1, 10.0, 2, this);
-    gainValidator->setNotation(QDoubleValidator::StandardNotation);
-    gainValidator->setLocale(QLocale::c());
-    ui->gain->setValidator(gainValidator);
-    auto polyphonyValidator = new QIntValidator(1, 65535, this);
-    ui->polyphony->setValidator(polyphonyValidator);
+    connect(ui->chorus_depth, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val / CHORUS_REVERB_VALUE_SCALE, 'f', 2);
+        ui->label_CDepth->setText(v);
+    });
+    connect(ui->chorus_level, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val / CHORUS_REVERB_VALUE_SCALE, 'f', 2);
+        ui->label_CLevel->setText(v);
+    });
+    connect(ui->chorus_nr, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val);
+        ui->label_CNR->setText(v);
+    });
+    connect(ui->chorus_speed, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val / CHORUS_REVERB_VALUE_SCALE, 'f', 2);
+        ui->label_CSpeed->setText(v);
+    });
+    connect(ui->reverb_damp, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val / CHORUS_REVERB_VALUE_SCALE, 'f', 2);
+        ui->label_RDamp->setText(v);
+    });
+    connect(ui->reverb_level, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val / CHORUS_REVERB_VALUE_SCALE, 'f', 2);
+        ui->label_RLevel->setText(v);
+    });
+    connect(ui->reverb_size, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val / CHORUS_REVERB_VALUE_SCALE, 'f', 2);
+        ui->label_RSize->setText(v);
+    });
+    connect(ui->reverb_width, &QAbstractSlider::valueChanged, this, [=](int val) {
+        QString v = QString::number(val / CHORUS_REVERB_VALUE_SCALE, 'f', 2);
+        ui->label_RWidth->setText(v);
+    });
 
     drumstick::rt::BackendManager man;
     m_driver = man.outputBackendByName("FluidSynth");
@@ -93,12 +124,10 @@ FluidSettingsDialog::FluidSettingsDialog(QWidget *parent) :
     ui->bufferTime->blockSignals(true);
     ui->periodSize->blockSignals(true);
     ui->periods->blockSignals(true);
-    //qDebug() << Q_FUNC_INFO;
 }
 
 FluidSettingsDialog::~FluidSettingsDialog()
 {
-    //qDebug() << Q_FUNC_INFO;
     if (m_driver != nullptr) {
         m_driver->close();
     }
@@ -107,34 +136,12 @@ FluidSettingsDialog::~FluidSettingsDialog()
 
 bool FluidSettingsDialog::checkRanges() const
 {
-    //qDebug() << Q_FUNC_INFO;
-    if (ui->gain->hasAcceptableInput()) {
-        ui->gain->deselect();
-    } else {
-        ui->gain->selectAll();
-    }
-    if (ui->polyphony->hasAcceptableInput()) {
-        ui->polyphony->deselect();
-    } else {
-        ui->polyphony->selectAll();
-    }
-    if (ui->sampleRate->hasAcceptableInput()) {
-        ui->sampleRate->deselect();
-    } else {
-        ui->sampleRate->selectAll();
-    }
-    return
-        ui->bufferTime->hasAcceptableInput() &&
-        ui->periodSize->hasAcceptableInput() &&
-        ui->periods->hasAcceptableInput() &&
-        ui->gain->hasAcceptableInput() &&
-        ui->polyphony->hasAcceptableInput() &&
-        ui->sampleRate->hasAcceptableInput();
+    return ui->bufferTime->hasAcceptableInput() && ui->periodSize->hasAcceptableInput()
+           && ui->periods->hasAcceptableInput();
 }
 
 void FluidSettingsDialog::accept()
 {
-    //qDebug() << Q_FUNC_INFO;
     if (checkRanges()) {
         writeSettings();
         if (m_driver != nullptr) {
@@ -183,7 +190,6 @@ QString FluidSettingsDialog::defaultAudioDriver() const
 
 void FluidSettingsDialog::chkDriverProperties(QSettings *settings)
 {
-    //qDebug() << Q_FUNC_INFO;
     if (m_driver != nullptr) {
         drumstick::rt::MIDIConnection conn;
         m_driver->close();
@@ -210,10 +216,15 @@ void FluidSettingsDialog::chkDriverProperties(QSettings *settings)
     }
 }
 
+void FluidSettingsDialog::setWidgetTip(QWidget *w, const QString &tip)
+{
+    w->setToolTip(tip);
+    QToolTip::showText(w->parentWidget()->mapToGlobal(w->pos()), tip);
+}
+
 void drumstick::widgets::FluidSettingsDialog::initBuffer()
 {
     if ((ui->audioDriver->currentText() == QSTR_PULSEAUDIO) && driverVersionLessThan_2_2_8()) {
-        //qDebug() << Q_FUNC_INFO << QSTR_PULSEAUDIO << driverVersion();
         int bufferTime = ui->bufferTime->value();
         int minBufTime = ui->bufferTime->minimum();
         if (bufferTime < minBufTime) {
@@ -222,7 +233,6 @@ void drumstick::widgets::FluidSettingsDialog::initBuffer()
         ui->bufferTime->setValue( bufferTime );
         bufferTimeChanged( bufferTime );
     } else {
-        //qDebug() << Q_FUNC_INFO;
         bufferSizeChanged();
     }
 }
@@ -248,19 +258,37 @@ bool FluidSettingsDialog::driverVersionLessThan_2_2_8()
 
 void FluidSettingsDialog::readSettings()
 {
-    //qDebug() << Q_FUNC_INFO;
     SettingsFactory settings;
     settings->beginGroup(QSTR_PREFERENCES);
     ui->audioDriver->setCurrentText( settings->value(QSTR_AUDIODRIVER, defaultAudioDriver()).toString() );
     ui->bufferTime->setValue( settings->value(QSTR_BUFFERTIME, DEFAULT_BUFFERTIME).toInt() );
     ui->periodSize->setValue( settings->value(QSTR_PERIODSIZE, DEFAULT_PERIODSIZE).toInt() );
     ui->periods->setValue( settings->value(QSTR_PERIODS, DEFAULT_PERIODS).toInt() );
-    ui->sampleRate->setText( settings->value(QSTR_SAMPLERATE, DEFAULT_SAMPLERATE).toString() );
-    ui->chorus->setChecked( settings->value(QSTR_CHORUS, DEFAULT_CHORUS).toInt() != 0 );
-    ui->reverb->setChecked( settings->value(QSTR_REVERB, DEFAULT_REVERB).toInt() != 0 );
-    ui->gain->setText( settings->value(QSTR_GAIN, DEFAULT_GAIN).toString() );
-    ui->polyphony->setText( settings->value(QSTR_POLYPHONY, DEFAULT_POLYPHONY).toString() );
+    ui->sampleRate->setCurrentText(settings->value(QSTR_SAMPLERATE, DEFAULT_SAMPLERATE).toString());
+    ui->gain->setValue(settings->value(QSTR_GAIN, DEFAULT_GAIN).toDouble());
+    ui->polyphony->setValue(settings->value(QSTR_POLYPHONY, DEFAULT_POLYPHONY).toInt());
     ui->soundFont->setText( settings->value(QSTR_INSTRUMENTSDEFINITION, m_defSoundFont).toString() );
+
+    ui->chorus_depth->setValue(settings->value(QSTR_CHORUS_DEPTH, DEFAULT_CHORUS_DEPTH).toDouble()
+                               * CHORUS_REVERB_VALUE_SCALE);
+    ui->chorus_level->setValue(settings->value(QSTR_CHORUS_LEVEL, DEFAULT_CHORUS_LEVEL).toDouble()
+                               * CHORUS_REVERB_VALUE_SCALE);
+    ui->chorus_nr->setValue(settings->value(QSTR_CHORUS_NR, DEFAULT_CHORUS_NR).toInt());
+    ui->chorus_speed->setValue(settings->value(QSTR_CHORUS_SPEED, DEFAULT_CHORUS_SPEED).toDouble()
+                               * CHORUS_REVERB_VALUE_SCALE);
+
+    ui->reverb_damp->setValue(settings->value(QSTR_REVERB_DAMP, DEFAULT_REVERB_DAMP).toDouble()
+                              * CHORUS_REVERB_VALUE_SCALE);
+    ui->reverb_level->setValue(settings->value(QSTR_REVERB_LEVEL, DEFAULT_REVERB_LEVEL).toDouble()
+                               * CHORUS_REVERB_VALUE_SCALE);
+    ui->reverb_size->setValue(settings->value(QSTR_REVERB_SIZE, DEFAULT_REVERB_SIZE).toDouble()
+                              * CHORUS_REVERB_VALUE_SCALE);
+    ui->reverb_width->setValue(settings->value(QSTR_REVERB_WIDTH, DEFAULT_REVERB_WIDTH).toDouble()
+                               * CHORUS_REVERB_VALUE_SCALE);
+
+    ui->chorus->setChecked(settings->value(QSTR_CHORUS, DEFAULT_CHORUS).toInt() != 0);
+    ui->reverb->setChecked(settings->value(QSTR_REVERB, DEFAULT_REVERB).toInt() != 0);
+
     settings->endGroup();
 
     audioDriverChanged( ui->audioDriver->currentText() );
@@ -269,7 +297,6 @@ void FluidSettingsDialog::readSettings()
 
 void FluidSettingsDialog::writeSettings()
 {
-    //qDebug() << Q_FUNC_INFO;
     SettingsFactory settings;
     QString audioDriver;
     QString soundFont(m_defSoundFont);
@@ -282,6 +309,16 @@ void FluidSettingsDialog::writeSettings()
     double  gain(DEFAULT_GAIN);
     int     polyphony(DEFAULT_POLYPHONY);
 
+    double chorus_depth(DEFAULT_CHORUS_DEPTH);
+    double chorus_level(DEFAULT_CHORUS_LEVEL);
+    int chorus_nr(DEFAULT_CHORUS_NR);
+    double chorus_speed(DEFAULT_CHORUS_SPEED);
+
+    double reverb_damp(DEFAULT_REVERB_DAMP);
+    double reverb_level(DEFAULT_REVERB_LEVEL);
+    double reverb_size(DEFAULT_REVERB_SIZE);
+    double reverb_width(DEFAULT_REVERB_WIDTH);
+
     audioDriver = ui->audioDriver->currentText();
     if (audioDriver.isEmpty()) {
         audioDriver = defaultAudioDriver();
@@ -290,11 +327,20 @@ void FluidSettingsDialog::writeSettings()
     bufferTime = ui->bufferTime->value();
     periodSize = ui->periodSize->value();
     periods = ui->periods->value();
-    sampleRate = ui->sampleRate->text().toDouble();
+    sampleRate = ui->sampleRate->currentText().toDouble();
     chorus = (ui->chorus->isChecked() ? 1 : 0);
     reverb = (ui->reverb->isChecked() ? 1 : 0);
-    gain = ui->gain->text().toDouble();
-    polyphony = ui->polyphony->text().toInt();
+    gain = ui->gain->value();
+    polyphony = ui->polyphony->value();
+
+    chorus_depth = ui->chorus_depth->value() / CHORUS_REVERB_VALUE_SCALE;
+    chorus_level = ui->chorus_level->value() / CHORUS_REVERB_VALUE_SCALE;
+    chorus_nr = ui->chorus_nr->value();
+    chorus_speed = ui->chorus_speed->value() / CHORUS_REVERB_VALUE_SCALE;
+    reverb_damp = ui->reverb_damp->value() / CHORUS_REVERB_VALUE_SCALE;
+    reverb_level = ui->reverb_level->value() / CHORUS_REVERB_VALUE_SCALE;
+    reverb_size = ui->reverb_size->value() / CHORUS_REVERB_VALUE_SCALE;
+    reverb_width = ui->reverb_width->value() / CHORUS_REVERB_VALUE_SCALE;
 
     settings->beginGroup(QSTR_PREFERENCES);
     settings->setValue(QSTR_INSTRUMENTSDEFINITION, soundFont);
@@ -307,6 +353,14 @@ void FluidSettingsDialog::writeSettings()
     settings->setValue(QSTR_REVERB, reverb);
     settings->setValue(QSTR_GAIN, gain);
     settings->setValue(QSTR_POLYPHONY, polyphony);
+    settings->setValue(QSTR_CHORUS_DEPTH, chorus_depth);
+    settings->setValue(QSTR_CHORUS_LEVEL, chorus_level);
+    settings->setValue(QSTR_CHORUS_NR, chorus_nr);
+    settings->setValue(QSTR_CHORUS_SPEED, chorus_speed);
+    settings->setValue(QSTR_REVERB_DAMP, reverb_damp);
+    settings->setValue(QSTR_REVERB_LEVEL, reverb_level);
+    settings->setValue(QSTR_REVERB_SIZE, reverb_size);
+    settings->setValue(QSTR_REVERB_WIDTH, reverb_width);
     settings->endGroup();
     settings->sync();
 
@@ -315,17 +369,24 @@ void FluidSettingsDialog::writeSettings()
 
 void FluidSettingsDialog::restoreDefaults()
 {
-    //qDebug() << Q_FUNC_INFO;
-    ui->audioDriver->setCurrentText( defaultAudioDriver() );
-    ui->bufferTime->setValue( DEFAULT_BUFFERTIME );
-    ui->periodSize->setValue( DEFAULT_PERIODSIZE );
-    ui->periods->setValue( DEFAULT_PERIODS );
-    ui->sampleRate->setText( QString::number( DEFAULT_SAMPLERATE ));
-    ui->chorus->setChecked( DEFAULT_CHORUS != 0 );
-    ui->reverb->setChecked( DEFAULT_REVERB != 0 );
-    ui->gain->setText( QString::number( DEFAULT_GAIN ) );
-    ui->polyphony->setText( QString::number( DEFAULT_POLYPHONY ));
-    ui->soundFont->setText( m_defSoundFont );
+    ui->audioDriver->setCurrentText(defaultAudioDriver());
+    ui->bufferTime->setValue(DEFAULT_BUFFERTIME);
+    ui->periodSize->setValue(DEFAULT_PERIODSIZE);
+    ui->periods->setValue(DEFAULT_PERIODS);
+    ui->sampleRate->setCurrentText(QString::number(DEFAULT_SAMPLERATE));
+    ui->gain->setValue(DEFAULT_GAIN);
+    ui->polyphony->setValue(DEFAULT_POLYPHONY);
+    ui->soundFont->setText(m_defSoundFont);
+    ui->chorus_depth->setValue(DEFAULT_CHORUS_DEPTH * CHORUS_REVERB_VALUE_SCALE);
+    ui->chorus_level->setValue(DEFAULT_CHORUS_LEVEL * CHORUS_REVERB_VALUE_SCALE);
+    ui->chorus_nr->setValue(DEFAULT_CHORUS_NR);
+    ui->chorus_speed->setValue(DEFAULT_CHORUS_SPEED * CHORUS_REVERB_VALUE_SCALE);
+    ui->reverb_damp->setValue(DEFAULT_REVERB_DAMP * CHORUS_REVERB_VALUE_SCALE);
+    ui->reverb_level->setValue(DEFAULT_REVERB_LEVEL * CHORUS_REVERB_VALUE_SCALE);
+    ui->reverb_size->setValue(DEFAULT_REVERB_SIZE * CHORUS_REVERB_VALUE_SCALE);
+    ui->reverb_width->setValue(DEFAULT_REVERB_WIDTH * CHORUS_REVERB_VALUE_SCALE);
+    ui->chorus->setChecked(DEFAULT_CHORUS != 0);
+    ui->reverb->setChecked(DEFAULT_REVERB != 0);
     initBuffer();
 }
 
@@ -335,15 +396,18 @@ void FluidSettingsDialog::showFileDialog()
     if (!dir.exists()) {
         dir = QDir(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QSTR_DATADIR2, QStandardPaths::LocateDirectory));
     }
-    QString fileName = QFileDialog::getOpenFileName(this, tr("Select SoundFont"), dir.absolutePath(), tr("SoundFont Files (*.sf2 *.sf3 *.dls)"));
-    if (!fileName.isEmpty()) {
-        ui->soundFont->setText(fileName);
+    QStringList fileNames
+        = QFileDialog::getOpenFileNames(this,
+                                        tr("Select SoundFont"),
+                                        dir.absolutePath(),
+                                        tr("SoundFont Files (*.sf2 *.sf3 *.dls)"));
+    if (!fileNames.isEmpty()) {
+        ui->soundFont->setText(fileNames.join(';'));
     }
 }
 
 void FluidSettingsDialog::audioDriverChanged(const QString &text)
 {
-    //qDebug() << Q_FUNC_INFO << text;
     if ((text == QSTR_PULSEAUDIO) && driverVersionLessThan_2_2_8()) {
         ui->bufferTime->setDisabled(false);
         ui->bufferTime->blockSignals(false);
@@ -366,24 +430,22 @@ void FluidSettingsDialog::audioDriverChanged(const QString &text)
 
 void FluidSettingsDialog::bufferTimeChanged(int value)
 {
-    double rate = ui->sampleRate->text().toDouble();
+    double rate = ui->sampleRate->currentText().toDouble();
     int size = qRound( value * rate / 1000.0 );
     ui->periodSize->setValue( size );
     ui->periods->setValue( ui->periods->minimum() );
-    //qDebug() << Q_FUNC_INFO << "time:" << value << "rate:" << rate << "size:" << size;
 }
 
 void FluidSettingsDialog::bufferSizeChanged()
 {
     QString audioDriver = ui->audioDriver->currentText();
-    double rate = ui->sampleRate->text().toDouble();
+    double rate = ui->sampleRate->currentText().toDouble();
     int size = ui->periodSize->value();
     if ((audioDriver != QSTR_PULSEAUDIO) || !driverVersionLessThan_2_2_8()) {
         size *= ui->periods->value();
     }
     int ms = qRound( 1000.0 * size / rate );
     ui->bufferTime->setValue(ms);
-    //qDebug() << Q_FUNC_INFO << "time:" << ms << "rate:" << rate << "size:" << size;
 }
 
 void FluidSettingsDialog::changeSoundFont(const QString& fileName)
