@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2024, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,10 @@
 #undef USE_QEVENTS
 //#define USE_QEVENTS
 
+/* Subscribe to Announce port to receive client and port events */
+#undef SUBSCRIBE_ANNOUNCE
+//#define SUBSCRIBE_ANNOUNCE
+
 /* To get timestamped events from ALSA, you need a running queue */
 //#undef WANT_TIMESTAMPS
 #define WANT_TIMESTAMPS
